Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Execute ¶
func Execute(projectVersion, commit, date string)
Execute adds all child commands to the root command and sets flags appropriately. This is called by main.main(). It only needs to happen once to the RootCmd.
func NewRootCmd ¶ added in v0.3.1
func ParseSigningMethod ¶
func ParseSigningMethod(alg string) (jwtlib.SigningMethod, error)
ParseSigningMethod returns the jwt.SigningMethod for the given algorithm name.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.